@@ -36,7 +36,7 @@
 
 #ifndef	lint
 static char *moduleid = 
-	"@(#)$Id: ascmagic.c,v 1.11 92/09/11 10:08:52 ian Exp $";
+	"@(#)$Id: ascmagic.c,v 1.14 93/03/24 17:34:34 ian Exp $";
 #endif	/* lint */
 
 			/* an optimisation over plain strcmp() */
@@ -49,7 +49,7 @@ int nbytes;	/* size actually read */
 {
 	int i, isblock, has_escapes = 0;
 	unsigned char *s;
-	char nbuf[HOWMANY];
+	char nbuf[HOWMANY+1];	/* one extra for terminating '\0' */
 	char *token;
 	register struct names *p;
 
@@ -80,11 +80,15 @@ int nbytes;	/* size actually read */
 	/* look for tokens from names.h - this is expensive! */
 	/* make a copy of the buffer here because strtok() will destroy it */
 	s = (unsigned char*) memcpy(nbuf, buf, HOWMANY);
+	has_escapes = (memchr(s, '\033', HOWMANY) != NULL);
 	while ((token = strtok((char*)s, " \t\n\r\f")) != NULL) {
 		s = NULL;	/* make strtok() keep on tokin' */
 		for (p = names; p < names + NNAMES; p++) {
 			if (STREQ(p->name, token)) {
 				ckfputs(types[p->type], stdout);
+				if (has_escapes)
+					ckfputs(" (with escape sequences)", 
+						stdout);
 				return 1;
 			}
 		}
@@ -119,17 +123,13 @@ int nbytes;	/* size actually read */
 	for (i = 0; i < nbytes; i++) {
 		if (!isascii(*(buf+i)))
 			return 0;	/* not all ascii */
-		if (*(buf+i) == '\033')	/* ascii ESCAPE */
-			has_escapes ++;
 	}
 
 	/* all else fails, but it is ascii... */
-	if (has_escapes){
-		ckfputs("ascii text (with escape sequences)", stdout);
-		}
-	else {
-		ckfputs("ascii text", stdout);
-		}
+	ckfputs("ascii text", stdout);
+	if (has_escapes) {
+		ckfputs(" (with escape sequences)", stdout);
+	}
 	return 1;
 }
 
